[![GitHub license](https://img.shields.io/github/license/Naereen/StrapDown.js.svg)](https://github.com/Naereen/StrapDown.js/blob/master/LICENSE)
[![Generic badge](https://img.shields.io/badge/Status-dev-orange.svg)](https://shields.io/)
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/Naereen/StrapDown.js/graphs/commit-activity)
[![Generic badge](https://img.shields.io/badge/Pypi-0.0.1a-blue.svg)](https://shields.io/)
[![Generic badge](https://img.shields.io/badge/Python-3.8-blue.svg)](https://shields.io/)

#### introduction

**`PyPipet`** is an open source project, aiming to integrate data flows in online retailing. It simplifies the data pipeline of ecommerce, for example, adding catalog, update product, manage inventory and orders, etc. It is customized for small business who are selling on wordpress (for example, with woocommerce), shopify, ebay, amazon, Paypal, etc. It extremely handy if the business is selling on multiple platforms. PyPipet is under dev. The latest version 0.0.1a. 

* For source code,  visit  [github repositoty](https://github.com/pypipet/pypipet).
* For documentation, vist [docs](https://pypipet.github.io/docs/)

#### [dependencies](/dependencies)

#### installation

    pip install pypipet

    or 

    pip3 install pypipet

#### to-do list

- [ ] connect to shopify
- [ ] connect to bigcommerce
- [ ] add email template
- [ ] UI
- [ ] connect to Google Analytics

#### [quick start guide](https://pypipet.github.io/docs//quick_start/create_project/)